/*
 * linux/arch/mips/vr41xx/setup.c
 *
 * VR41xx setup routines
 *
 * Copyright (C) 1999 Bradley D. LaRonde
 * Copyright (C) 1999, 2000 Michael Klar
 *
 * This file is subject to the terms and conditions of the GNU General Public
 * License.  See the file "COPYING" in the main directory of this archive
 * for more details.
 *
 */

#include <linux/config.h>
#include <linux/console.h>
#include <linux/ide.h>
#include <linux/init.h>
#include <linux/delay.h>
#include <linux/module.h>
#include <linux/bootmem.h>
#include <asm/reboot.h>
#include <asm/pci_channel.h>
#include <asm/vr41xx.h>
#include <asm/vr41xx/emma2.h>
#include <asm/vr41xx-platdep.h>
#include <asm/io.h>

struct semaphore vr41xx_dma_sem;

unsigned char *emma2_mpeg_mem = NULL;
int emma2_mpeg_mem_size = 0;

extern struct ide_ops vr41xx_ide_ops;
extern void vr41xx_restart(char* c);
extern void vr41xx_hibernate(void);

void platdep_setup(void) {}
#ifdef CONFIG_PCI
static struct resource vr41xx_pci_io_resource = {
	"PCI I/O space",
	VR41XX_PCI_IO_START,
	VR41XX_PCI_IO_END,
	IORESOURCE_IO
};

static struct resource vr41xx_pci_mem_resource = {
	"PCI memory space",
	VR41XX_PCI_MEM_START,
	VR41XX_PCI_MEM_END,
	IORESOURCE_MEM
};

extern struct pci_ops vr41xx_pci_ops;

struct pci_channel mips_pci_channels[] = {
	{&vr41xx_pci_ops, &vr41xx_pci_io_resource, &vr41xx_pci_mem_resource, 0, 1},
	{&vr41xx_pci_ops, &vr41xx_pci_io_resource, &vr41xx_pci_mem_resource, 0, 4},
	{NULL, NULL, NULL, 0, 0}
};

struct vr41xx_pci_address_space vr41xx_pci_mem1 = {
	VR41XX_PCI_MEM1_BASE,
	VR41XX_PCI_MEM1_MASK,
	IO_MEM1_RESOURCE_START
};

struct vr41xx_pci_address_space vr41xx_pci_mem2 = {
	VR41XX_PCI_MEM2_BASE,
	VR41XX_PCI_MEM2_MASK,
	IO_MEM2_RESOURCE_START
};

struct vr41xx_pci_address_space vr41xx_pci_io = {
	VR41XX_PCI_IO_BASE,
	VR41XX_PCI_IO_MASK,
	IO_PORT_RESOURCE_START
};

static struct vr41xx_pci_address_map pci_address_map = {
	&vr41xx_pci_mem1,
	&vr41xx_pci_mem2,
	&vr41xx_pci_io
};
#endif

void __init vr41xx_setup(void)
{
    	set_io_port_base( IO_PORT_BASE );
	isa_slot_offset = VR41XX_ISAMEM_BASE;

#ifdef CONFIG_BLK_DEV_IDE
	printk("setting ide_ops\n"); // DEBUG_JAN
	ide_nec_setup_hw();
	ide_ops = &vr41xx_ide_ops;
#endif

#ifdef CONFIG_FB
	conswitchp = &dummy_con;
#endif

	_machine_restart = vr41xx_restart;
	_machine_halt = vr41xx_hibernate;
	_machine_power_off = vr41xx_hibernate;

	// Insure that vr41xx_dma_sem is initialized as unlocked, even
	// in the case of a failed hibernate/wakeup:
	init_MUTEX(&vr41xx_dma_sem);

	// Do platform-dependent setup.
	// This is mostly stuff that doesn't fit well anywhere else.
	printk("platdep_setup\n"); // DEBUG_JAN
#ifdef CONFIG_PCI
	vr41xx_pciu_init(&pci_address_map);
#endif
	platdep_setup();
	printk("vr41xx setup done\n"); // DEBUG_JAN
//bdb
//	emma2_mpeg_mem = alloc_bootmem(16*1024*1024);
//	emma2_mpeg_mem_size = 16*1024*1024;
//	printk("emma2_mpeg_mem = %08x\n",emma2_mpeg_mem);
}

void bus_error_init()
{
}
